@@ -42,6 +42,7 @@
 #include "RecentBooksPopupData.h"
 #include "BookInfoDialog.h"
 #include "TimeUpdater.h"
+#include "FBColorSchemeFileHandler.h"
 
 #include "../libraryTree/LibraryView.h"
 #include "../network/NetworkLinkCollection.h"
@@ -51,6 +52,7 @@
 #include "../migration/migrate.h"
 
 #include "../options/FBCategoryKey.h"
+#include "../options/FBOptions.h"
 #include "../bookmodel/BookModel.h"
 #include "../formats/FormatPlugin.h"
 
@@ -157,6 +159,8 @@ FBReader::FBReader(const std::string &bookToOpen) :
 	addAction(ActionCode::ORGANIZE_BOOKS_BY_TAG, new BooksOrderAction(ActionCode::ORGANIZE_BOOKS_BY_TAG));
 	addAction(ActionCode::ORGANIZE_BOOKS_BY_NAME, new BooksOrderAction(ActionCode::ORGANIZE_BOOKS_BY_NAME));
 	addAction(ActionCode::FILTER_LIBRARY, new FilterLibraryAction());
+	addAction(ActionCode::SAVE_COLOR_SCHEME, new SaveColorSchemeAction());
+	addAction(ActionCode::LOAD_COLOR_SCHEME, new LoadColorSchemeAction());
 
 	myOpenFileHandler = new OpenFileHandler();
 	ZLCommunicationManager::Instance().registerHandler("openFile", myOpenFileHandler);
@@ -583,3 +587,26 @@ void FBReader::invalidateNetworkView() {
 void FBReader::invalidateAccountDependents() {
 	((NetworkView &) *myNetworkLibraryView).invalidateAccountDependents();
 }
+
+void FBReader::saveColorScheme() {
+	const ZLResourceKey dialogKey("saveColorSchemeDialog");
+	FBColorSchemeSaveHandler handler;
+	if (ZLDialogManager::Instance().selectionDialog(dialogKey, handler)) {
+		std::string filename = handler.selected();
+
+		saveConfigGroup("Colors", filename);
+	}
+}
+
+void FBReader::loadColorScheme() {
+	const ZLResourceKey dialogKey("loadColorSchemeDialog");
+	FBColorSchemeOpenHandler handler;
+	if (ZLDialogManager::Instance().selectionDialog(dialogKey, handler)) {
+		std::string filename = handler.selected();
+
+		loadConfigGroup("Colors", filename);
+		FBOptions::Instance().resynchColorOptions();
+
+		refreshWindow();
+	}
+}
