@@ -470,3 +470,11 @@ FilterLibraryAction::FilterLibraryAction() : ModeDependentAction(FBReader::LIBRA
 
 void FilterLibraryAction::run() {
 }
+
+void SaveColorSchemeAction::run() {
+	FBReader::Instance().saveColorScheme();
+}
+
+void LoadColorSchemeAction::run() {
+	FBReader::Instance().loadColorScheme();
+}
