@@ -31,7 +31,7 @@ public:
 	ZLBooleanOption IsSensitiveOption;
 	ZLBooleanOption ShowTextPositionOption;
 	ZLBooleanOption ShowTimeOption;
-	ZLBooleanOption ShowFSToggleOption;
+	ZLIntegerRangeOption ButtonOption;
 	ZLColorOption ColorOption;
 	ZLIntegerRangeOption HeightOption;
 	ZLIntegerRangeOption OffsetOption;
@@ -41,10 +41,11 @@ public:
 	FBIndicatorStyle();
 
 	Type type() const;
+	Button button() const;
 	bool isSensitive() const;
 	bool isTextPositionShown() const;
 	bool isTimeShown() const;
-	bool isFSToggleShown() const;
+	bool isButtonShown() const;
 	ZLColor color() const;
 	int height() const;
 	int offset() const;
