@@ -595,7 +595,8 @@ void XHTMLReader::beginParagraph() {
 		myModelReader.addControl(**it);
 		doBlockSpaceBefore =
 			doBlockSpaceBefore ||
-			(*it)->lengthSupported(ZLTextStyleEntry::LENGTH_MARGIN_BEFORE);
+			(*it)->lengthSupported(ZLTextStyleEntry::LENGTH_MARGIN_BEFORE) ||
+			(*it)->lengthSupported(ZLTextStyleEntry::LENGTH_PADDING_BEFORE);
 	}
 
 	if (doBlockSpaceBefore) {
@@ -605,6 +606,11 @@ void XHTMLReader::beginParagraph() {
 			0,
 			ZLTextStyleEntry::SIZE_UNIT_PIXEL
 		);
+		blockingEntry.setLength(
+			ZLTextStyleEntry::LENGTH_PADDING_BEFORE,
+			0,
+			ZLTextStyleEntry::SIZE_UNIT_PIXEL
+		);
 		myModelReader.addControl(blockingEntry);
 	}
 }
@@ -614,7 +620,8 @@ void XHTMLReader::endParagraph() {
 	for (std::vector<shared_ptr<ZLTextStyleEntry> >::const_iterator it = myStyleEntryStack.begin(); it != myStyleEntryStack.end() - myStylesToRemove; ++it) {
 		doBlockSpaceAfter =
 			doBlockSpaceAfter ||
-			(*it)->lengthSupported(ZLTextStyleEntry::LENGTH_MARGIN_AFTER);
+			(*it)->lengthSupported(ZLTextStyleEntry::LENGTH_MARGIN_AFTER) ||
+			(*it)->lengthSupported(ZLTextStyleEntry::LENGTH_PADDING_AFTER);
 	}
 	if (doBlockSpaceAfter) {
 		ZLTextStyleEntry blockingEntry;
@@ -623,6 +630,11 @@ void XHTMLReader::endParagraph() {
 			0,
 			ZLTextStyleEntry::SIZE_UNIT_PIXEL
 		);
+		blockingEntry.setLength(
+			ZLTextStyleEntry::LENGTH_PADDING_AFTER,
+			0,
+			ZLTextStyleEntry::SIZE_UNIT_PIXEL
+		);
 		myModelReader.addControl(blockingEntry);
 	}
 	for (; myStylesToRemove > 0; --myStylesToRemove) {
