@@ -91,7 +91,7 @@ NetworkLinkCollection::NetworkLinkCollection() :
 	shared_ptr<ZLDir> dir = ZLFile(NetworkLink::NetworkDataDirectory()).directory();
 	if (!dir.isNull()) {
 		std::vector<std::string> names;
-		dir->collectFiles(names, false);
+		dir->collectFiles(names, true);
 		for (std::vector<std::string>::iterator it = names.begin(); it != names.end(); ++it) {
 			shared_ptr<NetworkLink> link = OPDSLink::read(dir->itemPath(*it));
 			if (!link.isNull()) {
