@@ -143,6 +143,8 @@ MultiKeyOptionEntry::MultiKeyOptionEntry(const ZLResource &resource) :
 	addAction(ActionCode::SHOW_OPTIONS_DIALOG);
 	addAction(ActionCode::SHOW_BOOK_INFO_DIALOG);
 	addAction(ActionCode::ADD_BOOK);
+	addAction(ActionCode::SAVE_COLOR_SCHEME);
+	addAction(ActionCode::LOAD_COLOR_SCHEME);
 
 	// quit
 	addAction(ActionCode::CANCEL);
